@@ -18,6 +18,7 @@
 
 from functools import reduce
 import json
+from pydoc import cli
 import re
 import socket
 from threading import Thread
@@ -116,6 +117,7 @@ class HttpResponse:
         self.contentDisposition = ''
         self.cacheValue = None
         self.encoding = None
+        self.lineSep = '\r\n'
 
     def set_encoding(self, encoding:str):
         log_info(f'encoding set to {encoding}') ##TOKEN_TO_FIND
@@ -195,16 +197,16 @@ class HttpResponse:
     def __str__(self):
         if not self.cacheValue == None:
             return self.cacheValue
-        result = f"HTTP/1.1 {self.resposeStatus} {self.resposeText}\n"
+        result = f"HTTP/1.1 {self.resposeStatus} {self.resposeText}{self.lineSep}"
         if 'Location' not in self.headers: self.headers["Content-Length"] = len(self.body)
         if len(self.contentDisposition or '') > 0:
             self.headers['Content-Disposition'] = self.contentDisposition 
-        mappedHeaders = [f"{i}:{self.headers[i]}\n" for i in self.headers]
+        mappedHeaders = [f"{i}:{self.headers[i]}{self.lineSep}" for i in self.headers]
         for cookie in self.cookieHeaders:
             print(cookie)
-            mappedHeaders.append(f"Set-Cookie:{cookie}\n")
+            mappedHeaders.append(f"Set-Cookie:{cookie}{self.lineSep}")
         result += reduce(lambda a, b: a + b, mappedHeaders)
-        result += '\n'
+        result += f'{self.lineSep}'
         result += self.body
         log_info(f'response rendered') ##TOKEN_TO_FIND
         return result
@@ -219,6 +221,9 @@ class HttpResponse:
         log_info(f'cookie set: {name}={cookieString}') ##TOKEN_TO_FIND
         self.cookieHeaders.append(f"{name}={cookieString}")
 
+    def to_bytes(self) -> bytes:
+        return str(self).encode(self.encoding or 'latin1')
+
 class HttpRequest:
     __slots__ = [
         'clientAddress', 'raw', 'authorization', 
@@ -293,11 +298,16 @@ class Server(Thread):
     def on_receive(self, data:bytes, clientPort:socket.socket, clientAddress:str):
         raise NotImplementedError()
     
-    def on_accept(self, client:socket.socket, address:str):
+    def on_accept(self, client:socket.socket, address:str, readTimeout:int = None, closeSocket:bool = True):
+        self.on_receive(self.read(client, readTimeout), client, address)
+        if closeSocket:
+            client.close()
+
+    def read(self, client:socket.socket, readTimeout:int = None) -> bytes:
         data = []
         timeout = client.gettimeout()
         try:
-            client.settimeout(self.readTimeout)
+            client.settimeout(readTimeout or self.readTimeout)
             while True:
                 try:
                     buffer:bytes = client.recv(self.bufferSize)
@@ -308,8 +318,7 @@ class Server(Thread):
                     break
         finally:
             client.settimeout(timeout)
-        self.on_receive(bytes(data), client, address)
-        client.close()
+        return bytes(data)
         
     def next_free(self, port:int, max_port=65535):
         sock = self.get_socket()
@@ -333,7 +342,7 @@ class Server(Thread):
             log_warning(f'Port {self.port} already in use. Using port {port} instead.')
             self.port = port
         srv = self.get_socket()
-        srv.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 0)
+        srv.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         srv.bind((self.hostname, self.port))
         srv.listen(self.backlog)
         log_success(f'server sucessfully started') ##TOKEN_TO_FIND
