@@ -1,5 +1,7 @@
 from asyncio.subprocess import PIPE
 import subprocess
+from threading import Lock
+from typing import Any, Dict
 
 class PhpServer:
     def __init__(self, path:str, port:int = 80, address:str= 'localhost', phpBinPath:str='php') -> None:
@@ -22,4 +24,20 @@ class PhpServer:
         return self
     
     def stop(self):
-        self.process.kill()
\ No newline at end of file
+        self.process.kill()
+        
+class SharpLockLocks:
+    locks:Dict[int, Lock] = dict()  
+
+class SharpLock(SharpLockLocks):
+    def __init__(self, obj:Any):
+        self.lockid = id(obj)
+        if self.lockid not in SharpLockLocks.locks:
+            SharpLockLocks.locks[self.lockid] = Lock()
+    
+    def __enter__(self):
+        SharpLockLocks.locks[self.lockid].acquire()
+        return self
+    
+    def __exit__(self, type, value, traceback):
+        SharpLockLocks.locks[self.lockid].release()
\ No newline at end of file
